//------------------------------------------------------------------
//
//  For licensing information and to get the latest version go to:
//  http://workspaces.gotdotnet.com/3dtools
//
//------------------------------------------------------------------

using System;
using System.Diagnostics;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Media3D;

namespace ModelViewer
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void OnExit(object sender, RoutedEventArgs e)
        {
            Application.Current.Shutdown();
        }

        private void OnOpen(object sender, RoutedEventArgs e)
        {
            Microsoft.Win32.OpenFileDialog openFileDialog = new Microsoft.Win32.OpenFileDialog();

            if (openFileDialog.ShowDialog().Value)
            {
                _fileName = openFileDialog.FileName;
                Reload();
            }
        }

        private void OnRefresh(object sender, RoutedEventArgs e)
        {
            Reload();
        }

        private void OnHeadlightChecked(object sender, RoutedEventArgs e)
        {
            _trackport.HeadlightColor = Colors.White;
        }

        private void OnHeadlightUnchecked(object sender, RoutedEventArgs e)
        {
            _trackport.HeadlightColor = Colors.Black;
        }

        private void OnAmbientLightChecked(object sender, RoutedEventArgs e)
        {
            _trackport.AmbientLightColor = Colors.White;
        }

        private void OnAmbientLightUnchecked(object sender, RoutedEventArgs e)
        {
            _trackport.AmbientLightColor = Colors.Black;
        }

        private void Reload()
        {
            if (_fileName != null)
            {
                try
                {
                    using (FileStream file = File.OpenRead(_fileName))
                    {
                        _trackport.LoadModel(file);
                    }
                }
                catch (Exception e)
                {
                    MessageBox.Show(
                        String.Format("Unable to parse file:\r\n\r\n{0}",
                        e.Message), "Error", MessageBoxButton.OK, MessageBoxImage.Error);
                }
            }
        }

        private string _fileName;
    }
}